import { defineComponent } from "vue";
import axios from "@nextcloud/axios";
import { getCurrentUser } from "@nextcloud/auth";
import { generateUrl } from "@nextcloud/router";
import { spawnDialog } from "@nextcloud/dialogs";
import NcButton from "@nextcloud/vue/dist/Components/NcButton.js";
import NcDialog from "@nextcloud/vue/dist/Components/NcDialog.js";
import NcLoadingIcon from "@nextcloud/vue/dist/Components/NcLoadingIcon.js";
import NcPasswordField from "@nextcloud/vue/dist/Components/NcPasswordField.js";
import { getGettextBuilder } from "@nextcloud/l10n/gettext";
/*!
 * SPDX-FileCopyrightText: 2022 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: MIT
 */
const gtBuilder = getGettextBuilder().detectLocale();
[{ "locale": "ar", "translations": [{ "msgid": "Checking password …", "msgstr": ["يتم التحقق من كلمة المرور..."] }, { "msgid": "Confirm", "msgstr": ["تأكيد"] }, { "msgid": "Confirm your password", "msgstr": ["تأكيد كلمة المرور"] }, { "msgid": "Password", "msgstr": ["كلمة المرور"] }, { "msgid": "Please enter your password", "msgstr": ["يرجى إدخال كلمة المرور الخاصة بك"] }, { "msgid": "This action needs authentication", "msgstr": ["هذا الإجراء يتطلب التحقق من الهوية"] }, { "msgid": "Wrong password", "msgstr": ["كلمة المرور غير صحيحة"] }] }, { "locale": "ast", "translations": [{ "msgid": "Checking password …", "msgstr": ["Comprobando la contraseña…"] }, { "msgid": "Confirm", "msgstr": ["Confirmación"] }, { "msgid": "Confirm your password", "msgstr": ["Confirma la contraseña"] }, { "msgid": "Password", "msgstr": ["Contraseña"] }, { "msgid": "Please enter your password", "msgstr": ["Introduz la contraseña"] }, { "msgid": "This action needs authentication", "msgstr": ["Esta aición precisa l'autenticación"] }, { "msgid": "Wrong password", "msgstr": ["La contraseña ye incorreuta"] }] }, { "locale": "az", "translations": [{ "msgid": "Confirm", "msgstr": ["Təsdiq edin"] }, { "msgid": "Confirm your password", "msgstr": ["Parolunuzu təsdiq edin"] }, { "msgid": "Password", "msgstr": ["Parol"] }, { "msgid": "Password confirmation dialog already mounted", "msgstr": ["Parolun təsdiqi dialoqu artıq quraşdırılıb"] }, { "msgid": "This action needs authentication", "msgstr": ["Bu əməliyyat autentifikasiya tələb edir"] }, { "msgid": "Wrong password", "msgstr": ["Səhv parol"] }] }, { "locale": "be", "translations": [{ "msgid": "Checking password …", "msgstr": ["Праверка пароля…"] }, { "msgid": "Confirm", "msgstr": ["Пацвердзіць"] }, { "msgid": "Confirm your password", "msgstr": ["Пацвердзіць пароль"] }, { "msgid": "Password", "msgstr": ["Пароль"] }, { "msgid": "Please enter your password", "msgstr": ["Калі ласка, увядзіце ваш пароль"] }, { "msgid": "This action needs authentication", "msgstr": ["Гэта дзеянне патрабуе аўтэнтыфікацыі"] }, { "msgid": "Wrong password", "msgstr": ["Памылковы пароль"] }] }, { "locale": "ca", "translations": [{ "msgid": "Checking password …", "msgstr": ["S'està comprovant la contrasenya …"] }, { "msgid": "Confirm", "msgstr": ["Confirma"] }, { "msgid": "Confirm your password", "msgstr": ["Confirmeu la vostra contrasenya"] }, { "msgid": "Password", "msgstr": ["Contrasenya"] }, { "msgid": "Please enter your password", "msgstr": ["Introduïu la vostra contrasenya"] }, { "msgid": "This action needs authentication", "msgstr": ["Aquesta acció necessita autenticació"] }, { "msgid": "Wrong password", "msgstr": ["Contrasenya incorrecta"] }] }, { "locale": "cs_CZ", "translations": [{ "msgid": "Checking password …", "msgstr": ["Ověřování hesla…"] }, { "msgid": "Confirm", "msgstr": ["Potvrdit"] }, { "msgid": "Confirm your password", "msgstr": ["Zopakujte zadání hesla"] }, { "msgid": "Password", "msgstr": ["Heslo"] }, { "msgid": "Please enter your password", "msgstr": ["Zadejte heslo"] }, { "msgid": "This action needs authentication", "msgstr": ["Tato akce vyžaduje ověření se"] }, { "msgid": "Wrong password", "msgstr": ["Nesprávné heslo"] }] }, { "locale": "da", "translations": [{ "msgid": "Checking password …", "msgstr": ["Kontrollerer adgangskoden..."] }, { "msgid": "Confirm", "msgstr": ["Bekræft"] }, { "msgid": "Confirm your password", "msgstr": ["Bekræft din adgangskode"] }, { "msgid": "Password", "msgstr": ["Adgangskode"] }, { "msgid": "Please enter your password", "msgstr": ["Indtast venligst dit kodeord"] }, { "msgid": "This action needs authentication", "msgstr": ["Denne handling kræver godkendelse"] }, { "msgid": "Wrong password", "msgstr": ["forkert Adgangskode"] }] }, { "locale": "de", "translations": [{ "msgid": "Checking password …", "msgstr": ["Prüfe Passwort …"] }, { "msgid": "Confirm", "msgstr": ["Bestätigen"] }, { "msgid": "Confirm your password", "msgstr": ["Bestätige dein Passwort"] }, { "msgid": "Password", "msgstr": ["Passwort"] }, { "msgid": "Please enter your password", "msgstr": ["Bitte geben Sie Ihr Passwort ein"] }, { "msgid": "This action needs authentication", "msgstr": ["Diese Aktion benötigt eine Passwortbestätigung"] }, { "msgid": "Wrong password", "msgstr": ["Falsches Passwort"] }] }, { "locale": "de_DE", "translations": [{ "msgid": "Checking password …", "msgstr": ["Passwort prüfen …"] }, { "msgid": "Confirm", "msgstr": ["Bestätigen"] }, { "msgid": "Confirm your password", "msgstr": ["Bestätigen Sie Ihr Passwort"] }, { "msgid": "Password", "msgstr": ["Passwort"] }, { "msgid": "Please enter your password", "msgstr": ["Bitte geben Sie Ihr Passwort ein"] }, { "msgid": "This action needs authentication", "msgstr": ["Diese Aktion erfordert eine Authentifizierung"] }, { "msgid": "Wrong password", "msgstr": ["Falsches Passwort"] }] }, { "locale": "en_GB", "translations": [{ "msgid": "Checking password …", "msgstr": ["Checking password …"] }, { "msgid": "Confirm", "msgstr": ["Confirm"] }, { "msgid": "Confirm your password", "msgstr": ["Confirm your password"] }, { "msgid": "Password", "msgstr": ["Password"] }, { "msgid": "Please enter your password", "msgstr": ["Please enter your password"] }, { "msgid": "This action needs authentication", "msgstr": ["This action needs authentication"] }, { "msgid": "Wrong password", "msgstr": ["Wrong password"] }] }, { "locale": "es", "translations": [{ "msgid": "Checking password …", "msgstr": ["Verificando contraseña …"] }, { "msgid": "Confirm", "msgstr": ["Confirmar"] }, { "msgid": "Confirm your password", "msgstr": ["Confirme su contraseña"] }, { "msgid": "Password", "msgstr": ["Contraseña"] }, { "msgid": "Please enter your password", "msgstr": ["Por favor, Introduzca su contraseña"] }, { "msgid": "This action needs authentication", "msgstr": ["Esta acción necesita autenticación"] }, { "msgid": "Wrong password", "msgstr": ["Contraseña errónea"] }] }, { "locale": "es_AR", "translations": [{ "msgid": "Checking password …", "msgstr": ["Verificando contraseña …"] }, { "msgid": "Confirm", "msgstr": ["Confirmar"] }, { "msgid": "Confirm your password", "msgstr": ["Confirme su contraseña"] }, { "msgid": "Password", "msgstr": ["Contraseña"] }, { "msgid": "Please enter your password", "msgstr": ["Por favor, introduzca su contraseña"] }, { "msgid": "This action needs authentication", "msgstr": ["Esta acción necesita autenticación"] }, { "msgid": "Wrong password", "msgstr": ["Contraseña incorrecta"] }] }, { "locale": "es_MX", "translations": [{ "msgid": "Checking password …", "msgstr": ["Verificando contraseña …"] }, { "msgid": "Confirm", "msgstr": ["Confirmar"] }, { "msgid": "Confirm your password", "msgstr": ["Confirme su contraseña"] }, { "msgid": "Password", "msgstr": ["Contraseña"] }, { "msgid": "Please enter your password", "msgstr": ["Por favor introduzca su contraseña"] }, { "msgid": "This action needs authentication", "msgstr": ["Esta acción necesita autenticación"] }, { "msgid": "Wrong password", "msgstr": ["Contraseña incorrecta"] }] }, { "locale": "fa", "translations": [{ "msgid": "Checking password …", "msgstr": ["در حال بررسی رمز عبور …"] }, { "msgid": "Confirm", "msgstr": ["تأیید"] }, { "msgid": "Confirm your password", "msgstr": ["رمز عبور خود را تأیید کنید"] }, { "msgid": "Password", "msgstr": ["رمز عبور"] }, { "msgid": "Please enter your password", "msgstr": ["لطفاً رمز عبور خود را وارد کنید"] }, { "msgid": "This action needs authentication", "msgstr": ["این عمل نیاز به احراز هویت دارد"] }, { "msgid": "Wrong password", "msgstr": ["رمز عبور اشتباه است"] }] }, { "locale": "fi_FI", "translations": [{ "msgid": "Checking password …", "msgstr": ["Tarkistetaan salasanaa…"] }, { "msgid": "Confirm", "msgstr": ["Vahvista"] }, { "msgid": "Confirm your password", "msgstr": ["Vahvista salasanasi"] }, { "msgid": "Password", "msgstr": ["Salasana"] }, { "msgid": "Please enter your password", "msgstr": ["Kirjoita salasanasi"] }, { "msgid": "This action needs authentication", "msgstr": ["Tämä toiminto vaatii tunnistautumisen"] }, { "msgid": "Wrong password", "msgstr": ["Väärä salasana"] }] }, { "locale": "fr", "translations": [{ "msgid": "Checking password …", "msgstr": ["Vérification du mot de passe"] }, { "msgid": "Confirm", "msgstr": ["Confirmer"] }, { "msgid": "Confirm your password", "msgstr": ["Confirmez votre mot de passe"] }, { "msgid": "Password", "msgstr": ["Mot de passe"] }, { "msgid": "Please enter your password", "msgstr": ["Veuillez saisir votre mot de passe"] }, { "msgid": "This action needs authentication", "msgstr": ["Cette action nécessite une authentication"] }, { "msgid": "Wrong password", "msgstr": ["Mot de passe incorrect"] }] }, { "locale": "ga", "translations": [{ "msgid": "Checking password …", "msgstr": ["Pasfhocal á sheiceáil …"] }, { "msgid": "Confirm", "msgstr": ["Deimhnigh"] }, { "msgid": "Confirm your password", "msgstr": ["Deimhnigh do phasfhocal"] }, { "msgid": "Password", "msgstr": ["Pasfhocal"] }, { "msgid": "Please enter your password", "msgstr": ["Cuir isteach do phasfhocal"] }, { "msgid": "This action needs authentication", "msgstr": ["Teastaíonn fíordheimhniú ón ngníomh seo"] }, { "msgid": "Wrong password", "msgstr": ["Pasfhocal mícheart"] }] }, { "locale": "gl", "translations": [{ "msgid": "Checking password …", "msgstr": ["Comprobando o contrasinal…"] }, { "msgid": "Confirm", "msgstr": ["Confirmar"] }, { "msgid": "Confirm your password", "msgstr": ["Confirmar o seu contrasinal"] }, { "msgid": "Password", "msgstr": ["Contrasinal"] }, { "msgid": "Please enter your password", "msgstr": ["Introduza o seu contrasinal"] }, { "msgid": "This action needs authentication", "msgstr": ["Esta acción necesita autenticación"] }, { "msgid": "Wrong password", "msgstr": ["Contrasinal incorrecto"] }] }, { "locale": "hu_HU", "translations": [{ "msgid": "Checking password …", "msgstr": ["Jelszó ellenőrzése…"] }, { "msgid": "Confirm", "msgstr": ["Jóváhagyás"] }, { "msgid": "Confirm your password", "msgstr": ["Hagyja jóvá a jelszavát"] }, { "msgid": "Password", "msgstr": ["Jelszó"] }, { "msgid": "Please enter your password", "msgstr": ["Adja meg a jelszavát"] }, { "msgid": "This action needs authentication", "msgstr": ["A művelethez bejelentkezés szükséges"] }, { "msgid": "Wrong password", "msgstr": ["Hibás jelszó"] }] }, { "locale": "id", "translations": [{ "msgid": "Confirm", "msgstr": ["Konfirmasi"] }, { "msgid": "Confirm your password", "msgstr": ["Konfirmasi kata sandi Anda"] }, { "msgid": "Password", "msgstr": ["Kata sandi"] }, { "msgid": "Password confirmation dialog already mounted", "msgstr": ["Dialog konfirmasi kata sandi sudah dipasang"] }, { "msgid": "This action needs authentication", "msgstr": ["Tindakan ini memerlukan autentikasi"] }, { "msgid": "Wrong password", "msgstr": ["Kata sandi salah"] }] }, { "locale": "is", "translations": [{ "msgid": "Confirm", "msgstr": ["Staðfesta"] }, { "msgid": "Confirm your password", "msgstr": ["Staðfestu lykilorðið þitt"] }, { "msgid": "Password", "msgstr": ["Lykilorð"] }, { "msgid": "Password confirmation dialog already mounted", "msgstr": ["Gluggi fyrir staðfestingu á lykilorði er þegar tengdur"] }, { "msgid": "This action needs authentication", "msgstr": ["Þessi aðgerð krefst auðkenningar"] }, { "msgid": "Wrong password", "msgstr": ["Rangt lykilorð"] }] }, { "locale": "it", "translations": [{ "msgid": "Checking password …", "msgstr": ["Controllo della password…"] }, { "msgid": "Confirm", "msgstr": ["Conferma"] }, { "msgid": "Confirm your password", "msgstr": ["Conferma la tua password"] }, { "msgid": "Password", "msgstr": ["Password"] }, { "msgid": "Please enter your password", "msgstr": ["Inserisci la tua password"] }, { "msgid": "This action needs authentication", "msgstr": ["Questa azione richiede l'autenticazione"] }, { "msgid": "Wrong password", "msgstr": ["Password errata"] }] }, { "locale": "ja_JP", "translations": [{ "msgid": "Checking password …", "msgstr": ["パスワードのチェック ..."] }, { "msgid": "Confirm", "msgstr": ["確認"] }, { "msgid": "Confirm your password", "msgstr": ["パスワードの確認"] }, { "msgid": "Password", "msgstr": ["パスワード"] }, { "msgid": "Please enter your password", "msgstr": ["パスワードを入力してください"] }, { "msgid": "This action needs authentication", "msgstr": ["この操作には認証が必要です"] }, { "msgid": "Wrong password", "msgstr": ["間違ったパスワード"] }] }, { "locale": "lv", "translations": [{ "msgid": "Checking password …", "msgstr": ["Pārbauda paroli ..."] }, { "msgid": "Confirm", "msgstr": ["Apstiprināt"] }, { "msgid": "Confirm your password", "msgstr": ["Apstiprināt savu paroli"] }, { "msgid": "Password", "msgstr": ["Parole"] }, { "msgid": "Please enter your password", "msgstr": ["Lūgums ievadīt savu paroli"] }, { "msgid": "This action needs authentication", "msgstr": ["Šai darbībai ir nepieciešama autentificēšanās"] }, { "msgid": "Wrong password", "msgstr": ["Nepareiza parole"] }] }, { "locale": "ms_MY", "translations": [{ "msgid": "Checking password …", "msgstr": ["Memeriksa kata laluan ..."] }, { "msgid": "Confirm", "msgstr": ["Mengesahkan"] }, { "msgid": "Confirm your password", "msgstr": ["Mengesahkan kata laluan"] }, { "msgid": "Password", "msgstr": ["Kata laluan"] }, { "msgid": "Please enter your password", "msgstr": ["Sila masukkan kata laluan anda"] }, { "msgid": "This action needs authentication", "msgstr": ["Perbuatan ini memerlukan pengesahan"] }, { "msgid": "Wrong password", "msgstr": ["Kata laluan salah"] }] }, { "locale": "nb_NO", "translations": [{ "msgid": "Checking password …", "msgstr": ["Sjekker passord..."] }, { "msgid": "Confirm", "msgstr": ["Bekreft"] }, { "msgid": "Confirm your password", "msgstr": ["Bekreft passordet ditt"] }, { "msgid": "Password", "msgstr": ["Passord"] }, { "msgid": "Please enter your password", "msgstr": ["Vennligst skriv inn passordet ditt"] }, { "msgid": "This action needs authentication", "msgstr": ["Denne handlingen krever autentisering"] }, { "msgid": "Wrong password", "msgstr": ["Feil passord"] }] }, { "locale": "nl", "translations": [{ "msgid": "Checking password …", "msgstr": ["Wachtwoord controleren ..."] }, { "msgid": "Confirm", "msgstr": ["Bevestig"] }, { "msgid": "Confirm your password", "msgstr": ["Bevestig met je wachtwoord"] }, { "msgid": "Password", "msgstr": ["Wachtwoord"] }, { "msgid": "Please enter your password", "msgstr": ["Voer je wachtwoord in"] }, { "msgid": "This action needs authentication", "msgstr": ["Voor deze actie is authenticatie vereist"] }, { "msgid": "Wrong password", "msgstr": ["Wachtwoord verkeerd"] }] }, { "locale": "pl", "translations": [{ "msgid": "Checking password …", "msgstr": ["Sprawdzanie hasła…"] }, { "msgid": "Confirm", "msgstr": ["Potwierdź"] }, { "msgid": "Confirm your password", "msgstr": ["Potwierdź swoje hasło"] }, { "msgid": "Password", "msgstr": ["Hasło"] }, { "msgid": "Please enter your password", "msgstr": ["Wprowadź swoje hasło"] }, { "msgid": "This action needs authentication", "msgstr": ["Wykonanie tej czynności wymaga autoryzacji"] }, { "msgid": "Wrong password", "msgstr": ["Nieprawidłowe hasło"] }] }, { "locale": "pt_BR", "translations": [{ "msgid": "Checking password …", "msgstr": ["Verificando senha ..."] }, { "msgid": "Confirm", "msgstr": ["Confirmar"] }, { "msgid": "Confirm your password", "msgstr": ["Confirme sua senha"] }, { "msgid": "Password", "msgstr": ["Senha"] }, { "msgid": "Please enter your password", "msgstr": ["Por favor insira sua senha"] }, { "msgid": "This action needs authentication", "msgstr": ["Essa ação precisa ser autenticada"] }, { "msgid": "Wrong password", "msgstr": ["Senha incorreta"] }] }, { "locale": "ro", "translations": [{ "msgid": "Checking password …", "msgstr": ["Se verifică parola ..."] }, { "msgid": "Confirm", "msgstr": ["Confirmare"] }, { "msgid": "Confirm your password", "msgstr": ["Confirmare parolă"] }, { "msgid": "Password", "msgstr": ["Parolă"] }, { "msgid": "Please enter your password", "msgstr": ["Vă rugăm să introduceți parola"] }, { "msgid": "This action needs authentication", "msgstr": ["Această acțiune necesită autentificare"] }, { "msgid": "Wrong password", "msgstr": ["Parolă incorectă"] }] }, { "locale": "ru", "translations": [{ "msgid": "Checking password …", "msgstr": ["Проверка пароля …"] }, { "msgid": "Confirm", "msgstr": ["Подтвердить"] }, { "msgid": "Confirm your password", "msgstr": ["Подтвердите пароль"] }, { "msgid": "Password", "msgstr": ["Пароль"] }, { "msgid": "Please enter your password", "msgstr": ["Пожалуйста, введите свой пароль"] }, { "msgid": "This action needs authentication", "msgstr": ["Для этого действия требуется аутентификация"] }, { "msgid": "Wrong password", "msgstr": ["Неправильный пароль"] }] }, { "locale": "sk_SK", "translations": [{ "msgid": "Checking password …", "msgstr": ["Kontrola hesla..."] }, { "msgid": "Confirm", "msgstr": ["Potvrdiť"] }, { "msgid": "Confirm your password", "msgstr": ["Potvrďte svoje heslo"] }, { "msgid": "Password", "msgstr": ["Heslo"] }, { "msgid": "Please enter your password", "msgstr": ["Zadajte prosím svoje heslo"] }, { "msgid": "This action needs authentication", "msgstr": ["Táto akcia vyžaduje overenie"] }, { "msgid": "Wrong password", "msgstr": ["Nesprávne heslo"] }] }, { "locale": "sl", "translations": [{ "msgid": "Checking password …", "msgstr": ["Poteka preverjanje gesla ..."] }, { "msgid": "Confirm", "msgstr": ["Potrdi"] }, { "msgid": "Confirm your password", "msgstr": ["Potrdi geslo"] }, { "msgid": "Password", "msgstr": ["Geslo"] }, { "msgid": "Please enter your password", "msgstr": ["Vpisati je treba geslo"] }, { "msgid": "This action needs authentication", "msgstr": ["To dejanje zahteva overitev"] }, { "msgid": "Wrong password", "msgstr": ["Napačno geslo"] }] }, { "locale": "sr", "translations": [{ "msgid": "Checking password …", "msgstr": ["Лозинка се проверава…"] }, { "msgid": "Confirm", "msgstr": ["Потврда"] }, { "msgid": "Confirm your password", "msgstr": ["Потврдите своју лозинку"] }, { "msgid": "Password", "msgstr": ["Лозинка"] }, { "msgid": "Please enter your password", "msgstr": ["Молимо вас да унесете своју лозинку"] }, { "msgid": "This action needs authentication", "msgstr": ["За ову акцију је неопходна пријава"] }, { "msgid": "Wrong password", "msgstr": ["Погрешна лозинка"] }] }, { "locale": "sv", "translations": [{ "msgid": "Checking password …", "msgstr": ["Kontrollerar lösenord ..."] }, { "msgid": "Confirm", "msgstr": ["Bekräfta"] }, { "msgid": "Confirm your password", "msgstr": ["Bekräfta ditt lösenord"] }, { "msgid": "Password", "msgstr": ["Lösenord"] }, { "msgid": "Please enter your password", "msgstr": ["Ange ditt lösenord"] }, { "msgid": "This action needs authentication", "msgstr": ["Den här åtgärden behöver autentisering"] }, { "msgid": "Wrong password", "msgstr": ["Fel lösenord"] }] }, { "locale": "tr", "translations": [{ "msgid": "Checking password …", "msgstr": ["Parola dorulanıyor…"] }, { "msgid": "Confirm", "msgstr": ["Parola onayı"] }, { "msgid": "Confirm your password", "msgstr": ["Parola onayı"] }, { "msgid": "Password", "msgstr": ["Parola"] }, { "msgid": "Please enter your password", "msgstr": ["Lütfen parolanızı yazın"] }, { "msgid": "This action needs authentication", "msgstr": ["Bu işlem için kimliğin doğrulanması gereklidir"] }, { "msgid": "Wrong password", "msgstr": ["Parola geçersiz"] }] }, { "locale": "uk", "translations": [{ "msgid": "Checking password …", "msgstr": ["Перевірка паролю ..."] }, { "msgid": "Confirm", "msgstr": ["Підтвердити"] }, { "msgid": "Confirm your password", "msgstr": ["Підтвердіть ваш пароль"] }, { "msgid": "Password", "msgstr": ["Пароль"] }, { "msgid": "Please enter your password", "msgstr": ["Зазначте ваш пароль"] }, { "msgid": "This action needs authentication", "msgstr": ["Ця дія вимагає авторизації"] }, { "msgid": "Wrong password", "msgstr": ["Помилковий пароль"] }] }, { "locale": "zh_CN", "translations": [{ "msgid": "Checking password …", "msgstr": ["检查密码 ..."] }, { "msgid": "Confirm", "msgstr": ["确认"] }, { "msgid": "Confirm your password", "msgstr": ["确认你的密码"] }, { "msgid": "Password", "msgstr": ["密码"] }, { "msgid": "Please enter your password", "msgstr": ["请输入您的密码"] }, { "msgid": "This action needs authentication", "msgstr": ["此操作需要身份验证"] }, { "msgid": "Wrong password", "msgstr": ["密码错误"] }] }, { "locale": "zh_HK", "translations": [{ "msgid": "Checking password …", "msgstr": ["正在檢查密碼 …"] }, { "msgid": "Confirm", "msgstr": ["確認"] }, { "msgid": "Confirm your password", "msgstr": ["確認您的密碼"] }, { "msgid": "Password", "msgstr": ["密碼"] }, { "msgid": "Please enter your password", "msgstr": ["請輸入您的密碼"] }, { "msgid": "This action needs authentication", "msgstr": ["此操作需要進行身份驗證"] }, { "msgid": "Wrong password", "msgstr": ["密碼錯誤"] }] }, { "locale": "zh_TW", "translations": [{ "msgid": "Checking password …", "msgstr": ["正在檢查密碼……"] }, { "msgid": "Confirm", "msgstr": ["確認"] }, { "msgid": "Confirm your password", "msgstr": ["確認您的密碼"] }, { "msgid": "Password", "msgstr": ["密碼"] }, { "msgid": "Please enter your password", "msgstr": ["請輸入您的密碼"] }, { "msgid": "This action needs authentication", "msgstr": ["此動作需要驗證"] }, { "msgid": "Wrong password", "msgstr": ["密碼錯誤"] }] }].map(({ locale, translations }) => gtBuilder.addTranslation(locale, {
  translations: {
    "": Object.fromEntries(translations.map((t2) => [t2.msgid, t2]))
  }
}));
const gt = gtBuilder.build();
gt.ngettext.bind(gt);
const t = gt.gettext.bind(gt);
const _sfc_main = defineComponent({
  name: "PasswordDialog",
  components: {
    NcButton,
    NcDialog,
    NcLoadingIcon,
    NcPasswordField
  },
  props: {
    validate: {
      type: Function,
      default: () => {
      }
    }
  },
  data() {
    return {
      password: "",
      loading: false,
      showError: false
    };
  },
  computed: {
    helperText() {
      if (this.showError) {
        return this.password === "" ? t("Please enter your password") : t("Wrong password");
      }
      if (this.loading) {
        return t("Checking password …");
      }
      return "";
    }
  },
  mounted() {
    this.focusPasswordField();
  },
  methods: {
    t,
    async confirm() {
      this.showError = false;
      this.loading = true;
      if (this.password === "") {
        this.showError = true;
        return;
      }
      try {
        await this.validate(this.password);
        this.$emit("confirmed");
      } catch (e) {
        this.showError = true;
        this.selectPasswordField();
      } finally {
        this.loading = false;
      }
    },
    close(open) {
      if (!open) {
        this.$emit("close");
      }
    },
    focusPasswordField() {
      this.$nextTick(() => {
        this.$refs.field.focus();
      });
    },
    selectPasswordField() {
      this.$nextTick(() => {
        this.$refs.field.select();
      });
    }
  }
});
function normalizeComponent(scriptExports, render2, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render2) {
    options.render = render2;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  return {
    exports: scriptExports,
    options
  };
}
var _sfc_render = function render() {
  var _vm = this, _c = _vm._self._c;
  _vm._self._setupProxy;
  return _c("NcDialog", { attrs: { "name": _vm.t("Confirm your password"), "container": null, "content-classes": "vue-password-confirmation" }, on: { "update:open": _vm.close } }, [_c("p", [_vm._v(_vm._s(_vm.t("This action needs authentication")))]), _c("form", { staticClass: "vue-password-confirmation__form", on: { "submit": function($event) {
    $event.preventDefault();
    return _vm.confirm.apply(null, arguments);
  } } }, [_c("NcPasswordField", { ref: "field", attrs: { "value": _vm.password, "label": _vm.t("Password"), "helper-text": _vm.helperText, "error": _vm.showError, "required": "" }, on: { "update:value": function($event) {
    _vm.password = $event;
  } } }), _c("NcButton", { staticClass: "vue-password-confirmation__submit", attrs: { "type": "primary", "native-type": "submit", "disabled": !_vm.password || _vm.loading }, scopedSlots: _vm._u([_vm.loading ? { key: "icon", fn: function() {
    return [_c("NcLoadingIcon", { attrs: { "size": 20 } })];
  }, proxy: true } : null], null, true) }, [_vm._v(" " + _vm._s(_vm.t("Confirm")) + " ")])], 1)]);
};
var _sfc_staticRenderFns = [];
var __component__ = /* @__PURE__ */ normalizeComponent(
  _sfc_main,
  _sfc_render,
  _sfc_staticRenderFns
);
const PasswordDialogVue = __component__.exports;
/*!
 * SPDX-FileCopyrightText: 2022 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: MIT
 */
var PwdConfirmationMode = /* @__PURE__ */ ((PwdConfirmationMode2) => {
  PwdConfirmationMode2["Lax"] = "lax";
  PwdConfirmationMode2["Strict"] = "strict";
  return PwdConfirmationMode2;
})(PwdConfirmationMode || {});
/*!
 * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: MIT
 */
const PAGE_LOAD_TIME = Date.now();
let INTERCEPTOR_INITIALIZED = false;
const isPasswordConfirmationRequired = (mode) => {
  if (!window.backendAllowsPasswordConfirmation) {
    return false;
  }
  if (mode === PwdConfirmationMode.Strict) {
    return true;
  }
  const serverTimeDiff = PAGE_LOAD_TIME - window.nc_pageLoad * 1e3;
  const timeSinceLogin = Date.now() - (serverTimeDiff + window.nc_lastLogin * 1e3);
  return timeSinceLogin > 30 * 60 * 1e3;
};
const confirmPassword = () => {
  if (!isPasswordConfirmationRequired(PwdConfirmationMode.Lax)) {
    return Promise.resolve();
  }
  return new Promise((resolve, reject) => {
    promptPassword(
      async (password) => {
        await _confirmPassword(password);
        resolve();
      },
      () => reject(new Error("Dialog closed"))
    );
  });
};
async function _confirmPassword(password) {
  console.debug("Confirming password");
  const url = generateUrl("/login/confirm");
  const { data } = await axios.post(url, { password });
  window.nc_lastLogin = data.lastLogin;
  console.debug("Password confirmed");
}
function getDialog() {
  var _a;
  if (window._nc_password_confirmation_dialog === void 0) {
    console.debug("Prompting password form");
    const dialog = spawnDialog(PasswordDialogVue, {}, () => {
    });
    window._nc_password_confirmation_dialog = dialog;
  }
  return (_a = window._nc_password_confirmation_dialog) == null ? void 0 : _a.$children[0];
}
function promptPassword(validate, close) {
  const dialog = getDialog();
  dialog.$props.validate = validate;
  dialog.$on("confirmed", () => {
    dialog.$destroy();
    delete window._nc_password_confirmation_dialog;
  });
  dialog.$on("close", () => {
    dialog.$destroy();
    close();
    delete window._nc_password_confirmation_dialog;
  });
}
function addPasswordConfirmationInterceptors(axios2) {
  if (INTERCEPTOR_INITIALIZED) {
    return;
  }
  INTERCEPTOR_INITIALIZED = true;
  let validatePromise;
  axios2.interceptors.request.use(
    async (config) => {
      if (config.confirmPassword === void 0) {
        return config;
      }
      if (!isPasswordConfirmationRequired(config.confirmPassword)) {
        return config;
      }
      return new Promise((resolve, reject) => {
        promptPassword(
          async (password) => {
            var _a, _b;
            switch (config.confirmPassword) {
              case PwdConfirmationMode.Lax: {
                await _confirmPassword(password);
                resolve(config);
                return Promise.resolve();
              }
              case PwdConfirmationMode.Strict:
                console.debug("Adding auth info to the request", { config });
                config.auth = {
                  username: (_b = (_a = getCurrentUser()) == null ? void 0 : _a.uid) != null ? _b : "",
                  password
                };
                resolve(config);
                validatePromise = Promise.withResolvers();
                return validatePromise.promise;
            }
          },
          () => {
            reject(new Error("Dialog closed"));
          }
        );
      });
    }
  );
  axios2.interceptors.response.use(
    (response) => {
      if (response.config.confirmPassword !== PwdConfirmationMode.Strict) {
        return response;
      }
      console.debug("Password confirmation succeeded", { response });
      window.nc_lastLogin = Date.now() / 1e3;
      validatePromise.resolve();
      return response;
    },
    (error) => {
      var _a, _b;
      if (((_a = error.config) == null ? void 0 : _a.confirmPassword) !== PwdConfirmationMode.Strict) {
        throw error;
      }
      console.debug("Password confirmation failed", { error });
      validatePromise.reject(error);
      if (!(((_b = error.response) == null ? void 0 : _b.status) === 403 && error.response.data.message === "Password confirmation is required")) {
        throw error;
      }
      console.debug("Triggering new request", { error });
      return axios2.request(error.config);
    }
  );
}
export {
  PwdConfirmationMode,
  addPasswordConfirmationInterceptors,
  confirmPassword,
  isPasswordConfirmationRequired
};
